@@ -53,13 +53,12 @@ def get_data(documents,tags):
 
 def makeIndividualData(file,tags):
     connect = Grapher(file)
-    G, _, _ = connect.graph_formation()
-    df = connect.relative_distance(file.width,file.height)
-    individual_data = from_networkx(G)
+    individual_data = from_networkx(connect.G)
 
     feature_cols = ['rd_b', 'rd_r', 'rd_t', 'rd_l', 'line_number', \
                     'n_upper', 'n_alpha', 'n_spaces', 'n_numeric', 'n_special']
 
+    df = connect.df
     text_features = np.array(df["Object"].map(make_sent_bert_features).tolist()).astype(np.float32)
     numeric_features = df[feature_cols].values.astype(np.float32)
 
