@@ -2,9 +2,8 @@ import os
 import numpy as np
 import torch
 
-from graphmanagerlib.Graph import Grapher
+from graphmanagerlib.Complex_Graph import Grapher
 from graphmanagerlib.Data_for_gcn import getDataForUniquePrediction
-from torch_geometric.utils.convert import from_networkx
 from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects,ConvertPredictionToJson
 
 
